@@ -12,9 +12,10 @@ using std::binary_search;
 
 
 //[[Rcpp::export]]
-vector<string> add_to_namespace(const string dir_to_export,const string dir_to_file,const bool sorting){
-  int which_string_has_export=0,len_which_not_exp=1;
-  vector<string> newfiles=read_functions_and_signatures(dir_to_file)["export"],already_exported_files,which_not_exported;
+vector<string> add_to_namespace(const string dir_to_export,const string dir_to_file){
+  int which_string_has_export=0;
+  List functions=read_functions_and_signatures(dir_to_file)["export"];
+  vector<string> newfiles=functions["functions"],s3=functions["s3"],already_exported_files,which_not_exported;
   if(newfiles.empty()){
   	stop("Warning: empty folder.\n");
   }
@@ -22,44 +23,42 @@ vector<string> add_to_namespace(const string dir_to_export,const string dir_to_f
   if(which_string_has_export==-1){
   	stop("Error. can't find \"export\" function in NAMESPACE file with path \"%s\".\n",dir_to_export);
   }
-  string exported_files=data_export[which_string_has_export];
-  exported_files.erase(exported_files.end()-1);
-  exported_files.erase(exported_files.begin(),exported_files.begin()+7);
-  if(exported_files.size()==0 || sorting){
-    if(sorting){
-      exported_files.clear();
-    }
-    for(unsigned int i=0;i<newfiles.size();++i){
-        exported_files+=newfiles[i]+',';
-    }
-    which_not_exported=newfiles;
-    exported_files[exported_files.size()-1]=')';
-  }else{
-    already_exported_files=split_words(exported_files);
-    sort(already_exported_files.begin(),already_exported_files.end());
-    for(unsigned int i=0;i<newfiles.size();++i){
-      if(binary_search(already_exported_files.begin(),already_exported_files.end(),newfiles[i])==false){
-        exported_files+=','+newfiles[i];
-        which_not_exported.resize(len_which_not_exp);
-        which_not_exported[len_which_not_exp-1]=newfiles[i];
-        len_which_not_exp++;
-      }
-    }
-    exported_files+=')';
+  string exported_files;
+  sort(newfiles.begin(),newfiles.end());
+  sort(s3.begin(),s3.end());
+  
+  for(auto& newfile : newfiles){
+      exported_files+=newfile+',';
   }
+  exported_files[exported_files.size()-1]=')';
+  exported_files+="\n\n";
+  vector<string> s3_names;
+  for(auto& newfile : s3){
+    s3_names=split_words(newfile,".");
+    if(newfile[0]=='\"'){ // an einai tis morfis me "elem<-.iterator"
+      s3_names[0]+='\"';
+      s3_names[1].erase(s3_names[1].end()-1);
+    }
+    exported_files+="S3method("+s3_names[0]+","+s3_names[1]+")\n";
+  }
+  for(unsigned int i=which_string_has_export+1;i<data_export.size();++i){
+    if(is_s3method(data_export[i]))
+      data_export[i]="";
+  }
+  which_not_exported=newfiles;
+
   data_export[which_string_has_export]="export("+exported_files;
   writeFile(data_export,dir_to_export);
-  return which_not_exported;
+  return s3;
 }
 
-RcppExport SEXP Rfast_add_to_namespace(SEXP dir_to_exportSEXP,SEXP dir_to_fileSEXP,SEXP sortingSEXP) {
+RcppExport SEXP Rfast_add_to_namespace(SEXP dir_to_exportSEXP,SEXP dir_to_fileSEXP) {
 BEGIN_RCPP
     RObject __result;
     RNGScope __rngScope;
     traits::input_parameter< const string >::type dir_to_export(dir_to_exportSEXP);
     traits::input_parameter< const string >::type dir_to_file(dir_to_fileSEXP);
-    traits::input_parameter< const bool >::type sorting(sortingSEXP);
-    __result = add_to_namespace(dir_to_export,dir_to_file,sorting);
+    __result = wrap(add_to_namespace(dir_to_export,dir_to_file));
     return __result;
 END_RCPP
 }
@@ -83,7 +82,7 @@ vector<string> remove_from_namespace(const string dir_to_export,vector<string> f
     stop("Error. NAMESPACE file doesn't have any export function.\n");
   }else{
   	int len_unknown_files=1;
-    vector<string> already_exported_files=split_words(exported_files);
+    vector<string> already_exported_files=split_words(exported_files,",");
     sort(files_to_remove.begin(),files_to_remove.end());
     for(unsigned int i=0;i<already_exported_files.size();++i){
       if(binary_search(files_to_remove.begin(),files_to_remove.end(),already_exported_files[i])==false){
@@ -106,7 +105,7 @@ BEGIN_RCPP
     RNGScope __rngScope;
     traits::input_parameter< const string >::type dir_to_export(dir_to_exportSEXP);
     traits::input_parameter< vector<string> >::type files_to_remove(files_to_removeSEXP);
-    __result = remove_from_namespace(dir_to_export,files_to_remove);
+    __result = wrap(remove_from_namespace(dir_to_export,files_to_remove));
     return __result;
 END_RCPP
 }
