@@ -2,16 +2,15 @@
 
 using namespace Rcpp;
 using namespace arma;
-// [[Rcpp::depends(RcppArmadillo)]]
 
-//[[Rcpp::export]]
 List eigs_sym_c(NumericMatrix X,const int k, const bool vectors){
   List l;
   mat x(X.begin(),X.nrow(),X.ncol(),false);
+  sp_mat sx=conv_to<sp_mat>::from(x);
   vec eigval;
   mat eigvec;
 
-  eigs_sym( eigval, eigvec, conv_to<sp_mat>::from(x), k);
+  eigs_sym( eigval, eigvec, sx, k);
 
   l["values"] = flipud(eigval);
   
@@ -30,7 +29,7 @@ BEGIN_RCPP
     traits::input_parameter< NumericMatrix >::type X(XSEXP);
     traits::input_parameter< const int >::type k(kSEXP);
 	traits::input_parameter< const bool >::type vectors(vectorsSEXP);
-    __result = eigs_sym_c(X,k,vectors);
+    __result = wrap(eigs_sym_c(X,k,vectors));
     return __result;
 END_RCPP
 }
